@@ -29,17 +29,23 @@ from ..api import \
     IntegrationEnvironment, \
     IntegrationEvents
 
+from .integration_deferral_queue import \
+    IntegrationDeferralQueue
+
 from .integration_queue_context import \
-    IntegrationQueueContext, IntegrationQueueStatus
+    IntegrationQueueContext
 
 from .integration_time_context import \
-    IntegrationTimeContext, IntegrationTimeStatus
+    IntegrationTimeContext
 
 from .integration_webhook_context import \
-    IntegrationWebhookContext, IntegrationWebhookStatus
+    IntegrationWebhookContext, WebhookRouteStatus
 
 from .integration_ledger_context import \
-    IntegrationLedgerContext, IntegrationLedgerStatus
+    IntegrationLedgerContext, LedgerHandlerStatus
+
+from .package_metadata_introspection import \
+    get_daml_model_info
 
 from .common import \
     InvocationStatus, \
@@ -58,10 +64,11 @@ class IntegrationStatus:
     start_time: datetime
     error_message: 'Optional[str]'
     error_time: 'Optional[datetime]'
-    webhooks: 'Optional[IntegrationWebhookStatus]'
-    ledger: 'Optional[IntegrationLedgerStatus]'
-    timers: 'Optional[IntegrationTimeStatus]'
-
+    pending_events: int
+    webhooks: 'Sequence[WebhookRouteStatus]'
+    ledger_events: 'Sequence[LedgerHandlerStatus]'
+    timers: 'Sequence[InvocationStatus]'
+    queues: 'Sequence[InvocationStatus]'
 
 
 def normalize_metadata_field(field_value, field_type_info):
@@ -131,6 +138,8 @@ class IntegrationContext:
         self.error_message = None  # type: Optional[str]
         self.error_time = None  # type: Optional[datetime]
 
+        self.queue = IntegrationDeferralQueue()
+
         self.queue_context = None  # type: Optional[IntegrationQueueContext]
         self.time_context = None  # type: Optional[IntegrationTimeContext]
         self.webhook_context = None  # type: Optional[IntegrationWebhookContext]
@@ -180,8 +189,14 @@ class IntegrationContext:
     async def _load_and_start(self):
         metadata = self.integration_spec.metadata
 
+        LOG.info('Starting ledger client for party: %r', self.run_as_party)
+
         client = self.network.aio_party(self.run_as_party)
 
+        await client.ready()
+
+        LOG.info('Ledger client ready')
+
         env_class = self.get_integration_env_class(self.integration_type)
         entry_fn = self.get_integration_entrypoint(self.integration_type)
 
@@ -189,10 +204,12 @@ class IntegrationContext:
 
         LOG.info("Starting integration with metadata: %r", metadata)
 
-        self.queue_context = IntegrationQueueContext(client)
-        self.time_context = IntegrationTimeContext(client)
-        self.ledger_context = IntegrationLedgerContext(client)
-        self.webhook_context = IntegrationWebhookContext(client)
+        daml_model = get_daml_model_info();
+
+        self.queue_context = IntegrationQueueContext(self.queue, client)
+        self.time_context = IntegrationTimeContext(self.queue, client)
+        self.ledger_context = IntegrationLedgerContext(self.queue, client, daml_model)
+        self.webhook_context = IntegrationWebhookContext(self.queue, client)
 
         events = IntegrationEvents(
             queue=self.queue_context,
@@ -203,7 +220,8 @@ class IntegrationContext:
         integration_env_data = {
             **metadata,
             'queue': self.queue_context.sink,
-            'party': self.run_as_party
+            'party': self.run_as_party,
+            'daml_model': daml_model
             }
 
         integration_env = from_dict(
@@ -217,16 +235,13 @@ class IntegrationContext:
 
         user_coro = entry_fn(integration_env, events)
 
-        await client.ready()
-
         await self.ledger_context.process_sweeps()
 
         self.running = True
 
         int_coros = [
-            self.queue_context.start(),
+            self.queue.start(),
             self.time_context.start(),
-            self.ledger_context.start()
         ]
 
         if user_coro:
@@ -240,9 +255,11 @@ class IntegrationContext:
             start_time=self.start_time,
             error_message=self.error_message,
             error_time=self.error_time,
-            webhooks=self.webhook_context.get_status() if self.webhook_context else None,
-            ledger=self.ledger_context.get_status() if self.ledger_context else None,
-            timers=self.time_context.get_status() if self.time_context else None)
+            pending_events=self.queue.qsize(),
+            webhooks=self.webhook_context.get_status() if self.webhook_context else [],
+            ledger_events=self.ledger_context.get_status() if self.ledger_context else [],
+            timers=self.time_context.get_status() if self.time_context else [],
+            queues=self.queue_context.get_status() if self.queue_context else [])
 
     async def safe_load_and_start(self):
         try:
